@@ -10,12 +10,14 @@ import dice.utilities
 
 __all__ = ['roll', 'ParseException']
 __author__ = "Sam Clements <sam@borntyping.co.uk>"
-__version__ = '0.4.2'
+__version__ = '1.0.1'
 
 
 def roll(string, single=True, verbose=False):
     """Parses and evaluates a dice expression"""
     ast = dice.grammar.expression.parseString(string, parseAll=True)
+    if verbose:
+        dice.elements.Element.verbose = True
     result = [element.evaluate_cached(verbose=verbose) for element in ast]
     if single:
         return dice.utilities.single(result)
